@@ -4,8 +4,10 @@ use Carp;
 use Mouse;
 use Config::Model::Exception;
 use UNIVERSAL;
+use Path::Tiny;
 use File::Path;
 use Log::Log4perl qw(get_logger :levels);
+use 5.10.1;
 
 extends 'Config::Model::Backend::PlainFile';
 
@@ -98,11 +100,12 @@ sub write {
 
     # write data from leaf element from the node
     foreach my $elt ( $node->get_element_name() ) {
-        my $file = $dir . $elt;
+        my $file = path($dir)->child($elt);
 
         my $obj = $args{object}->fetch_element( name => $elt );
         my $type = $obj->get_type;
         my @v;
+        my $skip = 0;
 
         if ( $type eq 'leaf' ) {
             my $lv = $obj->fetch( check => $args{check} );
@@ -115,16 +118,18 @@ sub write {
             @v = map { "$_\n" } $obj->fetch_all_values;
         }
         else {
+            $skip = 1;
             $logger->debug("Dpkg write skipped $type $elt");
         }
 
         if (@v) {
             $logger->trace("Dpkg write opening $file to write");
-            my $fh = new IO::File;
-            $fh->open( $file, '>' ) or die "Cannot open $file:$!";
-            $fh->binmode(":utf8");
-            $fh->print(@v);
-            $fh->close;
+            $file->spew_utf8(@v) ;
+            $file->chmod("a+x") if $elt eq 'rules';
+        }
+        elsif ($args{auto_delete} and $file->is_file and not $skip) {
+            warn "deleting $file";
+            $file->remove;
         }
     }
 
