@@ -230,7 +230,7 @@ sub update ($self, %args) {
             my @sub_licenses = split /\s+or\s+/,$l;
             my $lic_count = 0;
             my @empty_licenses = grep {
-                my $text = $self->grab_value(qq!License:"$_" text!) ;
+                my $text = $self->grab_value(steps => qq!License:"$_" text!, check =>'no') ;
                 $ok++ if $text;
                 $lic_count += $lic_usage_count{$_} // 0 ;
                 not $text; # to get list of empty licenses
@@ -287,7 +287,7 @@ sub update ($self, %args) {
     # normalized again after all the modifications
     $self->load("Files:.sort");
 
-    $self->prune_unused_global_licenses;
+    $self->fetch_element("License")-> prune_unused_licenses;
 
     $self->instance->clear_changes; # too many changes to show users
     $self->notify_change(note => "updated copyright from source file"); # force a save
@@ -303,23 +303,6 @@ sub update ($self, %args) {
     return @msgs;
 }
 
-sub prune_unused_global_licenses ($self) {
-    my %global_license = map { $_ => 1 } $self->fetch_element("License")->fetch_all_indexes;
-
-    foreach my $path ($self->fetch_element('Files')->fetch_all_indexes) {
-        my $lic = $self->grab(qq!Files:"$path" License!);
-        next if $lic->fetch_element_value("full_license"); # no need of a global License
-        my $names = $lic->fetch_element_value("short_name") ;
-        my @sub_licenses = split /\s+or\s+/,$names;
-        map { delete $global_license{$_}; } @sub_licenses;
-    }
-
-    foreach my $obsolete_lic (sort keys %global_license) {
-        say "Deleting unused global license $obsolete_lic";
-        $self->load(qq!License:-"$obsolete_lic"!);
-    }
-}
-
 sub _apply_fix_scan_copyright_file ($self, $current_dir) {
     # read a debian/fix.scanned.copyright file to patch scanned data
     my $debian = $current_dir->child('debian'); # may be missing in test environment
