@@ -406,7 +406,10 @@ sub check_debhelper_version {
     }
 }
 
-my @deb_releases = qw/etch lenny squeeze wheezy/;
+# used with dependency filter: an optional config parameter which enable a user
+# to clean dependency older than a specified release. Be default, dependency version
+# are not cleaned up before they are older than old_stable.
+my @deb_releases = qw/etch lenny squeeze wheezy jessie stretch buster/;
 
 my %deb_release_h ;
 while (@deb_releases) {
@@ -850,7 +853,7 @@ sub get_available_version {
         return @res;
     }
 
-    my $url = "$madison_endpoint?package=".uri_escape($pkg_name).'&f' ;
+    my $url = "$madison_endpoint?package=".uri_escape($pkg_name).'&f&b=deb' ;
     $self->instance->show_message("Connecting to $madison_host to check $pkg_name versions. Please wait...") ;
 	my $body = get($url);
     my $res ;
@@ -894,7 +897,7 @@ sub cache_info_from_madison {
         return;
     }
 
-    my $url = "$madison_endpoint?package=".uri_escape(join(' ',@needed)).'&f' ;
+    my $url = "$madison_endpoint?package=".uri_escape(join(' ',@needed)).'&f&b=deb' ;
     $instance->show_message(
         "Connecting to $madison_host to check ", scalar @needed, " package versions. Please wait..."
     );
@@ -919,10 +922,21 @@ sub extract_madison_info ($json) {
         my %avail;
         foreach my $dist (keys $data->{$name}->%*) {
             foreach my $available_v (keys $data->{$name}{$dist}->%*) {
-                $avail{$available_v} = $dist;
+                my $arches = $data->{$name}{$dist}{$available_v}{architectures};
+                # see #841667: relevant pkg version is found in arch all or arch amd64
+                my @keep = grep { $_ eq 'all' or $_ eq 'amd64'} $arches->@*;
+
+                # the same version may be available in several
+                # distributions (testing and unstable are more likely
+                # to have the same version for a package)
+                $avail{$available_v} //= [];
+                push $avail{$available_v}->@*, $dist, $available_v if @keep;
             }
         }
-        my @res = map { ($avail{$_}, $_) ; } sort { $vs->compare($a,$b) } keys %avail ;
+
+        # @res contains something like 'oldstable 5.10.1-17 stable 5.14.2-21 testing 5.18.1-3 unstable 5.18.1-4'
+        my @res = map { $avail{$_}->@* ; } sort { $vs->compare($a,$b) } keys %avail ;
+
         $ref{$name} = \@res ;
         $cache{$name} = join(' ',time, @res) ;
 	}
