@@ -61,7 +61,7 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
             'msg' => 'Bad area. Should be \'non-free\' or \'contrib\''
           },
           'section' => {
-            'code' => '(not defined) or m!^([-\\w]+/)?(admin|cli-mono|comm|database|devel|debug|doc|editors|education|electronics|embedded|fonts|games|gnome|graphics|gnu-r|gnustep|hamradio|haskell|httpd|interpreters|introspection|java|kde|kernel|libs|libdevel|lisp|localization|mail|math|metapackages|misc|net|news|ocaml|oldlibs|otherosfs|perl|php|python|ruby|science|shells|sound|tex|text|utils|vcs|video|web|x11|xfce|zope)$!;',
+            'code' => '(not defined) or m!^([-\\w]+/)?(admin|cli-mono|comm|database|devel|debug|doc|editors|education|electronics|embedded|fonts|games|gnome|golang|graphics|gnu-r|gnustep|hamradio|haskell|httpd|interpreters|introspection|java|javascript|kde|kernel|libs|libdevel|lisp|localization|mail|math|metapackages|misc|net|news|ocaml|oldlibs|otherosfs|perl|php|python|ruby|rust|science|shells|sound|tex|text|utils|vcs|video|web|x11|xfce|zope)$!;',
             'msg' => 'Bad section.'
           }
         }
@@ -110,7 +110,9 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
             }
           }
         },
+        'description' => 'The Depends field should be used if the depended-on package is required for the depending package to provide a significant amount of functionality. See also L<debian policy|https://www.debian.org/doc/debian-policy/ch-relationships.html>',
         'duplicates' => 'warn',
+        'summary' => 'declares an absolute dependency.',
         'type' => 'list'
       },
       'Recommends',
@@ -120,7 +122,9 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'description' => 'This field should list packages that would be found together with this one in all but unusual installations. See also L<debian policy|https://www.debian.org/doc/debian-policy/ch-relationships.html>',
         'duplicates' => 'warn',
+        'summary' => 'declares a strong, but not absolute, dependency.',
         'type' => 'list'
       },
       'Suggests',
@@ -130,7 +134,9 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'description' => 'Using this field tells the packaging system and the user that the listed packages are related to this one and can perhaps enhance its usefulness, but that installing this one without them is perfectly reasonable. See also L<debian policy|https://www.debian.org/doc/debian-policy/ch-relationships.html> ',
         'duplicates' => 'warn',
+        'summary' => 'declare that one package may be more useful with one or more others.',
         'type' => 'list'
       },
       'Enhances',
@@ -140,6 +146,8 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'description' => 'This field is similar to Suggests but works in the opposite direction. It is used to declare that a package can enhance the functionality of another package. See also L<debian policy|https://www.debian.org/doc/debian-policy/ch-relationships.html>',
+        'summary' => 'declare that a package can enhance the functionality of another package',
         'type' => 'list'
       },
       'Pre-Depends',
@@ -149,6 +157,7 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'description' => 'This field is like Depends, except that it also forces dpkg to complete installation of the packages named before even starting the installation of the package which declares the pre-dependency.  See also L<debian policy|https://www.debian.org/doc/debian-policy/ch-relationships.html>',
         'type' => 'list'
       },
       'Breaks',
@@ -158,6 +167,7 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'description' => 'When one binary package declares that it breaks another, dpkg will refuse to allow the package which declares Breaks to be unpacked unless the broken package is deconfigured first, and it will refuse to allow the broken package to be reconfigured. See also L<debian policy|https://www.debian.org/doc/debian-policy/ch-relationships.html>',
         'type' => 'list'
       },
       'Conflicts',
@@ -167,6 +177,7 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'description' => 'When one binary package declares a conflict with another using a Conflicts field, dpkg will refuse to allow them to be unpacked on the system at the same time. This is a stronger restriction than Breaks, which prevents the broken package from being configured while the breaking package is in the "Unpacked" state but allows both packages to be unpacked at the same time. See also L<debian policy|https://www.debian.org/doc/debian-policy/ch-relationships.html>',
         'type' => 'list'
       },
       'Provides',
@@ -175,6 +186,7 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'description' => 'declare the functionality brought by this package. Be sure to read the chapter about virtual package in L<debian policy|https://www.debian.org/doc/debian-policy/ch-relationships.html> before using this parameter',
         'type' => 'list'
       },
       'Replaces',
@@ -184,6 +196,7 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
           'type' => 'leaf',
           'value_type' => 'uniline'
         },
+        'description' => 'declare that this package should overwrite files in certain other packages, or completely replace other packages. Be sure to read the section 7.6 of L<debian policy|https://www.debian.org/doc/debian-policy/ch-relationships.html> before using this parameter',
         'type' => 'list'
       },
       'Built-Using',
@@ -210,6 +223,7 @@ A package including binaries from grub2 and loadlin would have this field in its
 
      Built-Using: grub2 (= 1.99-9), loadlin (= 1.6e-1)',
         'duplicates' => 'warn',
+        'summary' => 'Additional source packages used to build the binary',
         'type' => 'list'
       },
       'Package-Type',
