@@ -94,7 +94,7 @@ area/section if the package is in the contrib or non-free archive areas.
             'msg' => 'Section is empty'
           },
           'section' => {
-            'code' => '(not defined) or m!^([-\\w]+/)?(admin|cli-mono|comm|database|devel|debug|doc|editors|education|electronics|embedded|fonts|games|gnome|graphics|gnu-r|gnustep|hamradio|haskell|httpd|interpreters|introspection|java|kde|kernel|libs|libdevel|lisp|localization|mail|math|metapackages|misc|net|news|ocaml|oldlibs|otherosfs|perl|php|python|ruby|science|shells|sound|tex|text|utils|vcs|video|web|x11|xfce|zope)$!;',
+            'code' => '(not defined) or m!^([-\\w]+/)?(admin|cli-mono|comm|database|devel|debug|doc|editors|education|electronics|embedded|fonts|games|gnome|golang|graphics|gnu-r|gnustep|hamradio|haskell|httpd|interpreters|introspection|java|javascript|kde|kernel|libs|libdevel|lisp|localization|mail|math|metapackages|misc|net|news|ocaml|oldlibs|otherosfs|perl|php|python|ruby|rust|science|shells|sound|tex|text|utils|vcs|video|web|x11|xfce|zope)$!;',
             'msg' => 'Bad section.'
           }
         }
@@ -105,26 +105,10 @@ area/section if the package is in the contrib or non-free archive areas.
         'status' => 'deprecated',
         'summary' => 'name of the non regression test suite',
         'type' => 'leaf',
-        'value_type' => 'uniline',
-        'warn_unless_match' => {
-          '^autopkgtest(-pkg-(perl|ruby))?$' => {
-            'fix' => '$_ = undef; # restore default value',
-            'msg' => 'Unknown value'
-          }
-        }
+        'value_type' => 'uniline'
       },
       'Testsuite',
       {
-        'compute' => {
-          'allow_override' => '1',
-          'formula' => 'my ($str) = ($team =~ /pkg-(perl|ruby)/);
-$str ? \'autopkgtest-pkg-\'.$str : undef;
-',
-          'use_eval' => '1',
-          'variables' => {
-            'team' => '- Maintainer'
-          }
-        },
         'description' => 'Enable a test suite to be used with this package. For more details see L<README.package-tests.rst|https://anonscm.debian.org/cgit/autopkgtest/autopkgtest.git/plain/doc/README.package-tests.rst>',
         'migrate_from' => {
           'formula' => '$xs_testsuite',
@@ -136,17 +120,30 @@ $str ? \'autopkgtest-pkg-\'.$str : undef;
         'type' => 'leaf',
         'value_type' => 'uniline',
         'warn_unless' => {
+          'defined-test' => {
+            'code' => 'my $m = $self->grab_value(\'- Maintainer\');
+my ($team) = ( $m =~ /(pkg-(?:perl|ruby))/ );
+not defined $team or defined $_;',
+            'fix' => 'my $m = $self->grab_value(\'- Maintainer\');
+my ($str) = ($m =~ /pkg-(perl|ruby)/);
+$_ = $str ? \'autopkgtest-pkg-\'.$str : undef;',
+            'msg' => 'Undefined while packaging team supports test suite'
+          },
           'team-test' => {
             'code' => 'my $m = $self->grab_value(\'- Maintainer\');
 my ($team) = ( $m =~ /(pkg-(?:perl|ruby))/ );
-not defined $team or $_ eq \'autopkgtest-\'.$team ;',
-            'fix' => '$_ = undef; # restore default value',
-            'msg' => 'Wrong team value'
+not defined $_ or not defined $team or $_ eq \'autopkgtest-\'.$team ;',
+            'fix' => 'my $m = $self->grab_value(\'- Maintainer\');
+my ($str) = ($m =~ /pkg-(perl|ruby)/);
+$_ = $str ? \'autopkgtest-pkg-\'.$str : undef;',
+            'msg' => 'value does not match maintainer team'
           }
         },
         'warn_unless_match' => {
           '^autopkgtest(-pkg-(perl|ruby))?$' => {
-            'fix' => '$_ = undef; # restore default value',
+            'fix' => 'my $m = $self->grab_value(\'- Maintainer\');
+my ($str) = ($m =~ /pkg-(perl|ruby)/);
+$_ = $str ? \'autopkgtest-pkg-\'.$str : undef;',
             'msg' => 'Unknown value'
           }
         }
@@ -292,15 +289,19 @@ Note that packages not wanted during "clean" phase must be declared in "Build-Co
       'Standards-Version',
       {
         'default' => '3.9.8',
-        'description' => 'This field indicates the Debian policy version number this package complies to',
+        'description' => 'This field indicates the Debian policy version number this package complies to.
+
+Before updating this field, please read L<upgrading-checklist|https://www.debian.org/doc/debian-policy/upgrading-checklist.html> to know what changes came with a new policy version number and apply the required changes (if any) to your package.',
         'match' => '\\d+\\.\\d+\\.\\d+(\\.\\d+)?',
         'summary' => 'Debian policy version number this package complies to',
         'type' => 'leaf',
         'value_type' => 'uniline',
-        'warn_unless_match' => {
-          '3\\.9\\.8' => {
+        'warn_unless' => {
+          'current' => {
+            'code' => '$_ eq $self->_fetch_std;',
             'fix' => '$_ = undef; # restore default value',
-            'msg' => 'Current standards version is 3.9.8'
+            'msg' => 'Current standards version is \'$std_value\'. Please read file:///usr/share/doc/debian-policy/upgrading-checklist.txt.gz to check what changes need to applied to your package to upgrade it from standard version \'$_\' to \'$std_value\'.
+'
           }
         }
       },
@@ -332,7 +333,7 @@ s{http://git.debian.org/\\?p=}{https://anonscm.debian.org/cgit/};
 s{http://anonscm.debian.org/gitweb/\\?p=}{https://anonscm.debian.org/cgit/};
 s{(https://anonscm.debian.org/cgit/.+);a=summary}{$1};
 s{http://bzr.debian.org/loggerhead/}{http://anonscm.debian.org/loggerhead/};',
-            'msg' => 'URL to debian system is not the recommended one'
+            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
           }
         }
       },
@@ -348,7 +349,7 @@ The information is meant to be useful for a user knowledgeable in the given Vers
           'debian-uri' => {
             'code' => '!defined $_ or ! /debian.org/ or m{^http://anonscm.debian.org/arch} ;',
             'fix' => 's!http://[\\w\\.-]+/(arch/)*!http://anonscm.debian.org/arch/!;',
-            'msg' => 'URL to debian system is not the recommended one'
+            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
           }
         }
       },
@@ -365,7 +366,7 @@ The information is meant to be useful for a user knowledgeable in the given Vers
             'code' => '!defined $_ or ! /debian.org/ or m{^http://anonscm.debian.org/bzr/} ;',
             'fix' => 's{http://\\w+.debian.org/(bzr/)*}{http://anonscm.debian.org/bzr/};
 ',
-            'msg' => 'URL to debian system is not the recommended one'
+            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
           }
         }
       },
@@ -382,7 +383,7 @@ The information is meant to be useful for a user knowledgeable in the given Vers
             'code' => '!defined $_ or ! /debian.org/ or m{\\@anonscm.debian.org:/cvs/} ;',
             'fix' => 's{\\@(?:cvs.alioth|anonscm)\\.debian\\.org:/cvsroot/}
                       {\\@anonscm.debian.org:/cvs/}',
-            'msg' => 'URL to debian system is not the recommended one'
+            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
           }
         }
       },
@@ -428,7 +429,7 @@ The information is meant to be useful for a user knowledgeable in the given Vers
             'code' => '!defined $_ or ! /debian.org/ or m{^https://anonscm.debian.org/git/(?!git/)};',
             'fix' => 's!http://[\\w\\.-]+/(git/)*!https://anonscm.debian.org/git/!;
 s!git://[\\w\\.-]+/(git/)?!https://anonscm.debian.org/git/!;',
-            'msg' => 'URL to debian system is not the recommended one'
+            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
           }
         }
       },
@@ -444,7 +445,7 @@ The information is meant to be useful for a user knowledgeable in the given Vers
           'debian-uri' => {
             'code' => '!defined $_ or ! /debian.org/ or m{^http://anonscm.debian.org/hg/};',
             'fix' => 's{http://\\w+.debian.org/(hg/)*}{http://anonscm.debian.org/hg/};',
-            'msg' => 'URL to debian system is not the recommended one'
+            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
           }
         }
       },
@@ -469,7 +470,7 @@ The information is meant to be useful for a user knowledgeable in the given Vers
           'debian-uri' => {
             'code' => '!defined $_ or ! /debian.org/ or m{^svn://anonscm.debian.org/} ;',
             'fix' => 's{svn://\\w+.debian.org/(svn/)*}{svn://anonscm.debian.org/};',
-            'msg' => 'URL to debian system is not the recommended one'
+            'msg' => 'URL is not the canonical one for repositories hosted on Alioth.'
           }
         }
       },
