@@ -66,7 +66,23 @@ you can fill like the C<Bug> field.',
       {
         'cargo' => {
           'type' => 'leaf',
-          'value_type' => 'uniline'
+          'value_type' => 'uniline',
+          'warn_if_match' => {
+            'https://bugs.debian.org/cgi-bin/bugreport\\.cgi\\?bug=' => {
+              'fix' => 's!/cgi-bin/bugreport\\.cgi\\?bug=!/!',
+              'msg' => 'You should use the simplified form of BTS URL'
+            }
+          },
+          'warn_unless_match' => {
+            '^https' => {
+              'fix' => 's!^http://!https://!',
+              'msg' => 'https protocol should be used instead of http'
+            },
+            '^https?://bugs\\.debian\\.org/' => {
+              'fix' => 's!https?://[^/]*!https://bugs.debian.org/!',
+              'msg' => 'Unknown host or protocol for Debian BTS'
+            }
+          }
         },
         'description' => 'This field contains one URL pointing to the related bug (possibly fixed by the patch). The Bug-Debian field is reserved for the bug URL in Debian BTS. Those fields can be used multiple times if several bugs are concerned.',
         'summary' => 'URL for related bug in Debian BTS',
