@@ -159,6 +159,7 @@ providing the following file:
     {
         # test for #713053,  XS-Ruby-Versions and XB-Ruby-Versions fields
         name => 'ruby',
+        apply_fix => 1, # to fix pkg-testsuite param
         check => {
             'source XS-Ruby-Versions' => 'all',
             'binary:libfast-xs-ruby XB-Ruby-Versions' => '${ruby:Versions}',
@@ -192,6 +193,13 @@ providing the following file:
             'binary:pkg-config-stage1 Build-Profiles' => '<stage1>',
             'source Build-Depends:3' => 'libglib2.0-dev <!stage1>'
         },
+    },
+
+    {
+        name => 'comments-in-dep-list',
+        file_contents_like => {
+            "debian/control" => qr/# Python/,
+        }
     }
 );
 
