@@ -141,6 +141,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
 
     { # t11 Debian bug #610231
+        # i.e. how to handle a file with missing info
         load_warnings => [  qr/insecure/, qr/Format does not match/ ],
         apply_fix => 1,
         dump_errors =>  [ 
@@ -315,14 +316,41 @@ in ‘/usr/share/common-licenses/GPL-1’.",
         apply_fix => 1,
         check => {
           'Files:"*" License short_name' => 'BSD-2-clause',
-          'Files:"a/*" License short_name' => 'my-BSD-3',
+          'Files:"a/*" License short_name' => 'BSD-like',
           'Files:"b/*" License short_name' => 'BSD-3-clause',
           'Files:"c/*" License short_name' => 'BSD-3-clause',
+          'Files:"d/*" License short_name' => 'my-BSD-3',
           'License:BSD-2-clause text' => 'yada',
           'License:BSD-3-clause text' => 'yada',
           'License:BSD-like text' => 'yada',
         }
     },
+    {
+        name => 'unused-license',
+        load_warnings => [ (qr/deprecated/) x 3 ],
+        # the unused license
+        check_before_fix => {
+            'License:"MPL-1.1" text'     => "[MPL-1.1 LICENSE TEXT]",
+        },
+
+        apply_fix => 1, # clean up unused license
+
+        # check that unused license was removed
+        has_not_key => [ 'License' => 'MPL-1.1' ],
+        check => {
+            'License:"GPL-2+" text'    => "[GPL-2 LICENSE TEXT]",
+            'License:"LGPL-2.1+" text' => "[LGPL-2.1 plus LICENSE TEXT]",
+            'Files:"src/js/editline/*" License short_name' =>
+              "GPL-2+ or LGPL-2.1+"
+        },
+
+    },
+    {
+        name => 'by-dh-make',
+        load_check => 'skip',
+#        load_warnings => [ (qr/deprecated/) x 3 ],
+
+    },
 );
 
 1;
