@@ -34,8 +34,26 @@ $skip = ( $@ or not -r '/etc/debian_version' ) ? 1 : 0;
         config_file => $conf_file_name,
         check => {
             'Synopsis' => qr/Configure.pl/,
+        },
+        # check that subject stays first field
+        file_contents_like => {
+            "$conf_dir/$conf_file_name" => [ qr/^Subject/ ] ,
         }
     },
+    {
+        name => 'by-git',
+        config_file => $conf_file_name,
+        dump_warnings => [ qr/Empty/ ],
+        check => {
+            Description => qr/enhance/,
+            diff => qr/@@ -7,7/
+        },
+        # check that description is first field
+        file_contents_like => {
+            "$conf_dir/$conf_file_name" => [ qr/^Description/ ] ,
+        }
+
+    },
 );
 
 
