@@ -16,6 +16,9 @@ $skip = ( $@ or not -r '/etc/debian_version' ) ? 1 : 0;
         # required to skip the bad patch (non dep-3)
         load_check => 'no',
         load_warnings => [ qr/Ignoring patch/ ],
+        check => {
+            'patches:tweak-defaults Synopsis' => 'Tweak defaults values for Debian'
+        },
         load => 'patches:~mail-like-patch',
         # bad patch is skipped by config-model but is not removed from patch set
         # hence the 2nd instance must also skip the bad patch
